@@ -165,6 +165,12 @@ struct c_block *f,*t;               // f (from) is source pointer
 
         if (f->ion_window[i] != NULLFLOAT)
             t->ion_window[i] = f->ion_window[i];
+
+        if (f->adhoc_file[i][0] != 0)
+            strcpy (t->adhoc_file[i], f->adhoc_file[i]);
+
+        if (f->adhoc_file_chans[i][0] != 0)
+            strcpy (t->adhoc_file_chans[i], f->adhoc_file_chans[i]);
         }
 
 
