@@ -72,7 +72,12 @@ struct c_block *cb_ptr;
     cb_ptr -> pc_amp_hcode    = 0.005;
     cb_ptr -> fmatch_bw_pct   = 25.0;
 
-                                                                      // vectors
+    for (i=0; i<2; i++)                              // clear ref and rem values
+        {
+        cb_ptr -> adhoc_file[i][0] = 0;
+        cb_ptr -> adhoc_file_chans[i][0] = 0;
+        }
+                      
     for (i=0; i<6; i++)
         cb_ptr -> adhoc_poly[i] = 0.0;       /* clear ad hoc phase polynomial */
 
