@@ -46,6 +46,8 @@ struct type_param
     double      ah_amp;                 /* Ad hoc sinusoid amplitude (rad) */
     double      ah_poly[6];             /* Ad hoc polynomial coefficients */
     int         ah_phase;               /* Ad hoc phase correction mode */
+    char        ah_file[2][256];        // file names for ad hoc file mode pcal
+    char        ah_file_chans[2][256];  // channel codes for ah_file contents
     unsigned long bocf_period;          /* Correlator frame in systicks */
     int         bocfs_per_ap;           /* Correlator frames per AP */
     short       su_number[2];           /* Ref and remote SU number */
