@@ -266,9 +266,6 @@ void pcalibrate (struct type_pass *pass,
                     pc_sub[stn] = c_mean (rotval, nin);
                 else
                     pc_sub[stn] = c_zero ();
-                                    // conjugate LSB phase to USB equivalent
-                if (fcenter < 0.0) 
-                    pc_sub[stn].im *= -1.0;
                                     // write this value into all ap's of sub-int.
                 for (kap=ap_subint_start; kap<=ap; kap++)
                     {
@@ -302,8 +299,6 @@ void pcalibrate (struct type_pass *pass,
                   pc_adj[stn].re = 1.0;
                   pc_adj[stn].im = 0.0;
                   }
-              if (fcenter < 0.0)    // conjugate LSB phase to USB equivalent
-                  pc_adj[stn].im *= -1.0;
               msg ("non-multitone pcal phasor %7.2f %7.2f", -1, 
                       1e3 * c_mag (pc_adj[stn]), 180.0 / M_PI * c_phase (pc_adj[stn]));
               }
